aboutsummaryrefslogtreecommitdiff
path: root/build.sh
diff options
context:
space:
mode:
Diffstat (limited to 'build.sh')
-rwxr-xr-xbuild.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/build.sh b/build.sh
index a2e3ca3..c494ef7 100755
--- a/build.sh
+++ b/build.sh
@@ -2,7 +2,7 @@
# build.sh - Build the custom Arch ZFS installation ISO
# Must be run as root
#
# Uses linux-lts kernel with zfs-dkms from archzfs.com repository.
# DKMS builds ZFS from source, ensuring it always matches the kernel version.
set -euo pipefail
@@ -151,7 +151,7 @@ info "Adding archzfs repository..."
cat >> "$PROFILE_DIR/pacman.conf" << 'EOF'
[archzfs]
-Server = https://archzfs.com/$repo/$arch
+Server = https://github.com/archzfs/archzfs/releases/download/experimental
SigLevel = Never
EOF
@@ -2,7 +2,7 @@
# Must be run as root
#
-# Uses linux-lts kernel with zfs-dkms from archzfs.com repository.
+# Uses linux-lts kernel with zfs-dkms from archzfs GitHub releases.
# DKMS builds ZFS from source, ensuring it always matches the kernel version.
set -euo pipefail